<?php

namespace Kiddles\Enrollment\Policies;

use Litepie\User\Contracts\UserPolicy;
use Kiddles\Enrollment\Models\Enrollment;

class EnrollmentPolicy
{

    /**
     * Determine if the given user can view the enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Enrollment $enrollment)
    {
        if ($user->canDo('enrollment.enrollment.view') && $user->isAdmin()) {
            return true;
        }

        return $enrollment->user_id == user_id() && $enrollment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('enrollment.enrollment.create');
    }

    /**
     * Determine if the given user can update the given enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Enrollment $enrollment)
    {
        if ($user->canDo('enrollment.enrollment.edit') && $user->isAdmin()) {
            return true;
        }

        return $enrollment->user_id == user_id() && $enrollment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Enrollment $enrollment)
    {
        return $enrollment->user_id == user_id() && $enrollment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Enrollment $enrollment)
    {
        if ($user->canDo('enrollment.enrollment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given enrollment.
     *
     * @param UserPolicy $user
     * @param Enrollment $enrollment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Enrollment $enrollment)
    {
        if ($user->canDo('enrollment.enrollment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
