<?php

namespace Kiddles\Enrollment\Providers;

use Illuminate\Support\ServiceProvider;

class EnrollmentServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'enrollment');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'enrollment');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEnrollment();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEnrollment()
    {
        $this->app->bind('enrollment', function($app) {
            return new Enrollment($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Enrollment', 'Lavalite\Enrollment\Facades\Enrollment');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('kiddles.enrollment', function ($app) {
            return $this->app->make('Kiddles\Enrollment\Enrollment');
        });

                // Bind Enrollment to repository
        $this->app->bind(
            'Kiddles\Enrollment\Interfaces\EnrollmentRepositoryInterface',
            \Kiddles\Enrollment\Repositories\Eloquent\EnrollmentRepository::class
        );

        $this->app->register(\Kiddles\Enrollment\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Kiddles\Enrollment\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and enrollment's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/enrollment.php', 'enrollment'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEnrollment::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['kiddles.enrollment'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('kiddles/enrollment.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/enrollment')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/enrollment')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
